*-----------------------------------------------------------------------
*     USPACK DRAW X-AXIS                              DCL 5.0  95/09/04
*-----------------------------------------------------------------------

      SUBROUTINE USXAXS(CSIDE)
      CHARACTER  CSIDE*1, CP*8
      LOGICAL    LMATCH

      IF(CSIDE.EQ.' ') RETURN

      CALL SGQTRN(ITR)
      CALL SGQVPT(VXMIN, VXMAX, VYMIN, VYMAX)
      CALL SGQWND(UXMIN, UXMAX, UYMIN, UYMAX)

      IF(ITR.EQ.1 .OR. ITR.EQ.2) THEN
        CP = 'IROTLX'//CSIDE
        CALL UZIGET(CP, IROTA)
        CALL USLGET('LMATCH'       , LMATCH)
        MODE = MOD(IROTA,2)
        IF(LMATCH) MODE = 0

        CALL USUSCU('X', UXMIN, UXMAX, VXMIN, VXMAX, MODE)
        CALL USXAXU(CSIDE)

      ELSEIF(ITR.EQ.3 .OR. ITR.EQ.4) THEN
        CALL USUSCL('X', UXMIN, UXMAX, VXMIN, VXMAX)
        CALL USXAXL(CSIDE)
      ELSE
        CALL MSGDMP('E', 'USXAXS', 'INVALID TRANSFORMATION NUMBER.')
      ENDIF

      RETURN
      END
